diff --git a/src/ipa/rpi/cam_helper/cam_helper_imx219.cpp b/src/ipa/rpi/cam_helper/cam_helper_imx219.cpp
index ba01153ebecf..c9e5479aa67a 100644
--- a/src/ipa/rpi/cam_helper/cam_helper_imx219.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper_imx219.cpp
@@ -44,7 +44,7 @@ public:
 	CamHelperImx219();
 	uint32_t gainCode(double gain) const override;
 	double gain(uint32_t gainCode) const override;
-	unsigned int mistrustFramesModeSwitch() const override;
+	unsigned int mistrustMetadataModeSwitch() const override;
 	bool sensorEmbeddedDataPresent() const override;
 
 private:
@@ -77,7 +77,7 @@ double CamHelperImx219::gain(uint32_t gainCode) const
 	return 256.0 / (256 - gainCode);
 }
 
-unsigned int CamHelperImx219::mistrustFramesModeSwitch() const
+unsigned int CamHelperImx219::mistrustMetadataModeSwitch() const
 {
 	/*
 	 * For reasons unknown, we do occasionally get a bogus metadata frame
diff --git a/src/ipa/rpi/cam_helper/cam_helper_imx355.cpp b/src/ipa/rpi/cam_helper/cam_helper_imx355.cpp
index 00e5fc836433..e6cac83be3be 100644
--- a/src/ipa/rpi/cam_helper/cam_helper_imx355.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper_imx355.cpp
@@ -20,7 +20,7 @@ public:
 	CamHelperImx355();
 	uint32_t gainCode(double gain) const override;
 	double gain(uint32_t gainCode) const override;
-	unsigned int mistrustFramesModeSwitch() const override;
+	unsigned int mistrustMetadataModeSwitch() const override;
 	bool sensorEmbeddedDataPresent() const override;
 
 private:
@@ -46,7 +46,7 @@ double CamHelperImx355::gain(uint32_t gainCode) const
 	return 1024.0 / (1024 - gainCode);
 }
 
-unsigned int CamHelperImx355::mistrustFramesModeSwitch() const
+unsigned int CamHelperImx355::mistrustMetadataModeSwitch() const
 {
 	/*
 	 * For reasons unknown, we do occasionally get a bogus metadata frame
diff --git a/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp b/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
index 40d6b6d76452..3b6fbb17ad96 100644
--- a/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
@@ -19,8 +19,8 @@ public:
 	double gain(uint32_t gainCode) const override;
 	unsigned int hideFramesStartup() const override;
 	unsigned int hideFramesModeSwitch() const override;
-	unsigned int mistrustFramesStartup() const override;
-	unsigned int mistrustFramesModeSwitch() const override;
+	unsigned int mistrustMetadataStartup() const override;
+	unsigned int mistrustMetadataModeSwitch() const override;
 
 private:
 	/*
@@ -68,7 +68,7 @@ unsigned int CamHelperOv5647::hideFramesModeSwitch() const
 	return 2;
 }
 
-unsigned int CamHelperOv5647::mistrustFramesStartup() const
+unsigned int CamHelperOv5647::mistrustMetadataStartup() const
 {
 	/*
 	 * First couple of frames are under-exposed and are no good for control
@@ -77,7 +77,7 @@ unsigned int CamHelperOv5647::mistrustFramesStartup() const
 	return 2;
 }
 
-unsigned int CamHelperOv5647::mistrustFramesModeSwitch() const
+unsigned int CamHelperOv5647::mistrustMetadataModeSwitch() const
 {
 	/*
 	 * First couple of frames are under-exposed even after a simple
diff --git a/src/ipa/rpi/cam_helper/cam_helper.cpp b/src/ipa/rpi/cam_helper/cam_helper.cpp
index dfdcd167839a..ce0040137519 100644
--- a/src/ipa/rpi/cam_helper/cam_helper.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper.cpp
@@ -192,13 +192,13 @@ unsigned int CamHelper::hideFramesModeSwitch() const
 	return 0;
 }
 
-unsigned int CamHelper::mistrustFramesStartup() const
+unsigned int CamHelper::mistrustMetadataStartup() const
 {
 	/* Many sensors return a single bad frame on start-up. */
 	return 1;
 }
 
-unsigned int CamHelper::mistrustFramesModeSwitch() const
+unsigned int CamHelper::mistrustMetadataModeSwitch() const
 {
 	/* Many sensors return valid metadata immediately. */
 	return 0;
@@ -192,13 +192,13 @@ unsigned int CamHelper::hideFramesModeSwitch() const
 {
-	/* Many sensors return a single bad frame on start-up. */
+	/* Many sensors return bad metadata on the first frame after start-up. */
 	return 1;
 }
diff --git a/src/ipa/rpi/cam_helper/cam_helper.h b/src/ipa/rpi/cam_helper/cam_helper.h
index bd101895f23e..5a022d305f7e 100644
--- a/src/ipa/rpi/cam_helper/cam_helper.h
+++ b/src/ipa/rpi/cam_helper/cam_helper.h
@@ -56,12 +56,12 @@ namespace RPiController {
  * HideFramesModeSwitch(): Tell the pipeline handler not to return this
  *     many frames after a mode switch (other than start-up). Some sensors
  *     may produce innvalid frames after a mode switch; others may not.
  * MistrustFramesStartup(): At start-up a sensor may return frames for
  *    which we should not run any control algorithms (for example, metadata
  *    may be invalid).
  * MistrustFramesModeSwitch(): The number of frames, after a mode switch
  *    (other than start-up), for which control algorithms should not run
  *    (for example, metadata may be unreliable).
  * getMinDebinFactor(): the binning factor after which we should apply
  *    "debinning", which corrects for the uneven spatial sampling of the
  *    standard binning process. A return value of 2 means to enable
@@ -96,8 +96,8 @@ public:
 	virtual double getModeSensitivity(const CameraMode &mode) const;
 	virtual unsigned int hideFramesStartup() const;
 	virtual unsigned int hideFramesModeSwitch() const;
-	virtual unsigned int mistrustFramesStartup() const;
-	virtual unsigned int mistrustFramesModeSwitch() const;
+	virtual unsigned int mistrustMetadataStartup() const;
+	virtual unsigned int mistrustMetadataModeSwitch() const;
 	virtual unsigned int getMinDebinFactor() const;
 
 protected:
@@ -56,12 +56,12 @@ namespace RPiController {
  *     many frames after a mode switch (other than start-up). Some sensors
  *     may produce innvalid frames after a mode switch; others may not.
- * MistrustFramesStartup(): At start-up a sensor may return frames for
- *    which we should not run any control algorithms (for example, metadata
- *    may be invalid).
- * MistrustFramesModeSwitch(): The number of frames, after a mode switch
- *    (other than start-up), for which control algorithms should not run
- *    (for example, metadata may be unreliable).
+ * mistrustMetadataStartup(): At start-up, a sensor may return this number of
+ *     frames with invalid metadata. This metadata cannot be relied upon by the
+ *     control algorithms.
+ * mistrustMetadataModeSwitch():  On a mode switch, a sensor may return this
+ *     number of frames with invalid metadata. This metadata cannot be relied
+ *     upon by the control algorithms.
  * getMinDebinFactor(): the binning factor after which we should apply
  *    "debinning", which corrects for the uneven spatial sampling of the
diff --git a/src/ipa/rpi/common/ipa_base.cpp b/src/ipa/rpi/common/ipa_base.cpp
index dacafa578c98..aa17d39fea7b 100644
--- a/src/ipa/rpi/common/ipa_base.cpp
+++ b/src/ipa/rpi/common/ipa_base.cpp
@@ -351,12 +351,12 @@ void IpaBase::start(const ControlList &controls, StartResult *result)
 	frameCount_ = 0;
 	if (firstStart_) {
 		invalidCount_ = helper_->hideFramesStartup();
-		mistrustCount_ = helper_->mistrustFramesStartup();
+		mistrustCount_ = helper_->mistrustMetadataStartup();
 
 		/*
 		 * Query the AGC/AWB for how many frames they may take to
 		 * converge sufficiently. Where these numbers are non-zero
 		 * we must allow for the frames with bad statistics
 		 * (mistrustCount_) that they won't see. But if zero (i.e.
 		 * no convergence necessary), no frames need to be dropped.
 		 */
@@ -377,7 +377,7 @@ void IpaBase::start(const ControlList &controls, StartResult *result)
 		}
 	} else {
 		invalidCount_ = helper_->hideFramesModeSwitch();
-		mistrustCount_ = helper_->mistrustFramesModeSwitch();
+		mistrustCount_ = helper_->mistrustMetadataModeSwitch();
 	}
 
 	result->startupFrameCount = std::max({ agcConvergenceFrames, awbConvergenceFrames });
@@ -351,12 +351,12 @@ void IpaBase::start(const ControlList &controls, StartResult *result)
 		 * Query the AGC/AWB for how many frames they may take to
 		 * converge sufficiently. Where these numbers are non-zero
-		 * we must allow for the frames with bad statistics
+		 * we must allow for the frames with bad metadata
 		 * (mistrustCount_) that they won't see. But if zero (i.e.
 		 * no convergence necessary), no frames need to be dropped.
